==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/ug.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "نامەلۇم ئادرېس",
    "No result." : "ھېچقانداق نەتىجە يوق.",
    "Malformed JSON data." : "JSON سانلىق مەلۇماتلىرى ئۆزگەرتىلدى.",
    "Error" : "خاتالىق",
    "Weather status" : "ھاۋارايى ئەھۋالى",
    "Weather status in your dashboard" : "باشقۇرۇش تاختىڭىزدىكى ھاۋارايى ئەھۋالى",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "باش تاختا دېتالىغا بىرلەشتۈرۈلگەن ھاۋارايى ئەھۋالى.\n    جۇغراپىيىلىك ئورۇننى ئاپتوماتىك بەلگىلىگىلى ياكى قولدا بەلگىلىگىلى بولىدۇ. ئاندىن 6 سائەتلىك پەرەز كۆرسىتىلىدۇ.\n    بۇ ھالەتنى كالېندار دېتالىغا ئوخشاش باشقا جايلارغىمۇ بىرلەشتۈرگىلى بولىدۇ.",
    "Detect location" : "ئورۇننى ئېنىقلاڭ",
    "Set custom address" : "ئىختىيارى ئادرېس بەلگىلەڭ",
    "Favorites" : "يىغقۇچ",
    "{temperature} {unit} clear sky later today" : "بۈگۈن {temperature} {unit} سۈزۈك ئاسمان",
    "{temperature} {unit} clear sky" : "{temperature} {unit} سۈزۈك ئاسمان",
    "{temperature} {unit} cloudy later today" : "بۈگۈن {temperature} {unit} بۇلۇتلۇق",
    "{temperature} {unit} cloudy" : "{temperature} {unit} بۇلۇتلۇق",
    "{temperature} {unit} snow and thunder later today" : "بۈگۈن {temperature} {unit} قار ۋە گۈلدۈرمامىلىق يامغۇر",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} قار ۋە گۈلدۈرماما",
    "{temperature} {unit} snow showers and thunder later today" : "بۈگۈن {temperature} {unit} قار ياغىدۇ ۋە گۈلدۈرماما",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} قار يامغۇر ۋە گۈلدۈرمامىلىق يامغۇر}",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "بۈگۈن {temperature} {unit}",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} قار ياغىدۇ ، گۈلدۈرمامىلىق ۋە شىمالىي قۇتۇپ شەپەق نۇرى",
    "{temperature} {unit} snow showers later today" : "بۈگۈن {temperature} {unit} قار ياغدى",
    "{temperature} {unit} snow showers" : "{temperature} {unit} قار ياغىدۇ}",
    "{temperature} {unit} snow showers and polar twilight later today" : "بۈگۈن {temperature} {unit} قار ياغىدۇ ۋە شىمالىي قۇتۇپ نۇرى",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} قار ياغىدۇ ۋە قۇتۇپ شەپەق نۇرى}",
    "{temperature} {unit} snow later today" : "بۈگۈن {temperature} {unit} قار",
    "{temperature} {unit} snow" : "{temperature} {unit} قار",
    "{temperature} {unit} fair weather later today" : "بۈگۈن {temperature} {unit} ئادىل ھاۋارايى",
    "{temperature} {unit} fair weather" : "{temperature} {unit} ئادىل ھاۋارايى",
    "{temperature} {unit} partly cloudy later today" : "بۈگۈن {temperature} {unit} قىسمەن بۇلۇتلۇق",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} قىسمەن بۇلۇتلۇق",
    "{temperature} {unit} foggy later today" : "بۈگۈن {temperature} {unit} تۇمانلىق",
    "{temperature} {unit} foggy" : "{temperature} {unit} تۇمانلىق",
    "{temperature} {unit} light rainfall later today" : "بۈگۈن {temperature} {unit} ئازراق يامغۇر",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} ئازراق يامغۇر",
    "{temperature} {unit} rainfall later today" : "بۈگۈن {temperature} {unit} يامغۇر",
    "{temperature} {unit} rainfall" : "{temperature} {unit} يامغۇر",
    "{temperature} {unit} heavy rainfall later today" : "بۈگۈن {temperature} {unit} قاتتىق يامغۇر",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} قاتتىق يامغۇر",
    "{temperature} {unit} rainfall showers later today" : "بۈگۈن {temperature} {unit} يامغۇر ياغدى",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} يامغۇرلۇق يامغۇر",
    "{temperature} {unit} light rainfall showers later today" : "بۈگۈن {temperature} {unit} ئازراق يامغۇر ياغىدۇ",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} ئازراق يامغۇر ياغىدۇ",
    "{temperature} {unit} heavy rainfall showers later today" : "بۈگۈن {temperature} {unit} قاتتىق يامغۇر ياغىدۇ",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} قاتتىق يامغۇر ياغىدۇ",
    "More weather for {adr}" : "تېخىمۇ كۆپ ھاۋارايى {adr}",
    "Loading weather" : "ھاۋا رايى",
    "Set location for weather" : "ھاۋارايىغا ئورۇن بەلگىلەڭ",
    "Remove from favorites" : "Remove from favorites",
    "Add as favorite" : "ياقتۇرىدىغاندەك قوشۇڭ",
    "You are not logged in." : "سىز كىرمىدىڭىز.",
    "There was an error getting the weather status information." : "ھاۋارايى ئەھۋالى ئۇچۇرىغا ئېرىشىشتە خاتالىق كۆرۈلدى.",
    "No weather information found" : "ھاۋارايى ئۇچۇرى تېپىلمىدى",
    "Location not found" : "ئورنى تېپىلمىدى",
    "There was an error setting the location address." : "ئورۇن ئادرېسىنى تەڭشەشتە خاتالىق كۆرۈلدى.",
    "There was an error setting the location." : "ئورۇن بەلگىلەشتە خاتالىق كۆرۈلدى.",
    "There was an error saving the mode." : "ھالەتنى ساقلاشتا خاتالىق كۆرۈلدى.",
    "There was an error using personal address." : "شەخسىي ئادرېسنى ئىشلىتىپ خاتالىق كۆرۈلدى.",
    "Unknown weather code" : "نامەلۇم ھاۋارايى كودى"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/weather_status/l10n/ug.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "نامەلۇم ئادرېس",
    "No result." : "ھېچقانداق نەتىجە يوق.",
    "Malformed JSON data." : "JSON سانلىق مەلۇماتلىرى ئۆزگەرتىلدى.",
    "Error" : "خاتالىق",
    "Weather status" : "ھاۋارايى ئەھۋالى",
    "Weather status in your dashboard" : "باشقۇرۇش تاختىڭىزدىكى ھاۋارايى ئەھۋالى",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "باش تاختا دېتالىغا بىرلەشتۈرۈلگەن ھاۋارايى ئەھۋالى.\n    جۇغراپىيىلىك ئورۇننى ئاپتوماتىك بەلگىلىگىلى ياكى قولدا بەلگىلىگىلى بولىدۇ. ئاندىن 6 سائەتلىك پەرەز كۆرسىتىلىدۇ.\n    بۇ ھالەتنى كالېندار دېتالىغا ئوخشاش باشقا جايلارغىمۇ بىرلەشتۈرگىلى بولىدۇ.",
    "Detect location" : "ئورۇننى ئېنىقلاڭ",
    "Set custom address" : "ئىختىيارى ئادرېس بەلگىلەڭ",
    "Favorites" : "يىغقۇچ",
    "{temperature} {unit} clear sky later today" : "بۈگۈن {temperature} {unit} سۈزۈك ئاسمان",
    "{temperature} {unit} clear sky" : "{temperature} {unit} سۈزۈك ئاسمان",
    "{temperature} {unit} cloudy later today" : "بۈگۈن {temperature} {unit} بۇلۇتلۇق",
    "{temperature} {unit} cloudy" : "{temperature} {unit} بۇلۇتلۇق",
    "{temperature} {unit} snow and thunder later today" : "بۈگۈن {temperature} {unit} قار ۋە گۈلدۈرمامىلىق يامغۇر",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} قار ۋە گۈلدۈرماما",
    "{temperature} {unit} snow showers and thunder later today" : "بۈگۈن {temperature} {unit} قار ياغىدۇ ۋە گۈلدۈرماما",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} قار يامغۇر ۋە گۈلدۈرمامىلىق يامغۇر}",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "بۈگۈن {temperature} {unit}",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} قار ياغىدۇ ، گۈلدۈرمامىلىق ۋە شىمالىي قۇتۇپ شەپەق نۇرى",
    "{temperature} {unit} snow showers later today" : "بۈگۈن {temperature} {unit} قار ياغدى",
    "{temperature} {unit} snow showers" : "{temperature} {unit} قار ياغىدۇ}",
    "{temperature} {unit} snow showers and polar twilight later today" : "بۈگۈن {temperature} {unit} قار ياغىدۇ ۋە شىمالىي قۇتۇپ نۇرى",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} قار ياغىدۇ ۋە قۇتۇپ شەپەق نۇرى}",
    "{temperature} {unit} snow later today" : "بۈگۈن {temperature} {unit} قار",
    "{temperature} {unit} snow" : "{temperature} {unit} قار",
    "{temperature} {unit} fair weather later today" : "بۈگۈن {temperature} {unit} ئادىل ھاۋارايى",
    "{temperature} {unit} fair weather" : "{temperature} {unit} ئادىل ھاۋارايى",
    "{temperature} {unit} partly cloudy later today" : "بۈگۈن {temperature} {unit} قىسمەن بۇلۇتلۇق",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} قىسمەن بۇلۇتلۇق",
    "{temperature} {unit} foggy later today" : "بۈگۈن {temperature} {unit} تۇمانلىق",
    "{temperature} {unit} foggy" : "{temperature} {unit} تۇمانلىق",
    "{temperature} {unit} light rainfall later today" : "بۈگۈن {temperature} {unit} ئازراق يامغۇر",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} ئازراق يامغۇر",
    "{temperature} {unit} rainfall later today" : "بۈگۈن {temperature} {unit} يامغۇر",
    "{temperature} {unit} rainfall" : "{temperature} {unit} يامغۇر",
    "{temperature} {unit} heavy rainfall later today" : "بۈگۈن {temperature} {unit} قاتتىق يامغۇر",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} قاتتىق يامغۇر",
    "{temperature} {unit} rainfall showers later today" : "بۈگۈن {temperature} {unit} يامغۇر ياغدى",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} يامغۇرلۇق يامغۇر",
    "{temperature} {unit} light rainfall showers later today" : "بۈگۈن {temperature} {unit} ئازراق يامغۇر ياغىدۇ",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} ئازراق يامغۇر ياغىدۇ",
    "{temperature} {unit} heavy rainfall showers later today" : "بۈگۈن {temperature} {unit} قاتتىق يامغۇر ياغىدۇ",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} قاتتىق يامغۇر ياغىدۇ",
    "More weather for {adr}" : "تېخىمۇ كۆپ ھاۋارايى {adr}",
    "Loading weather" : "ھاۋا رايى",
    "Set location for weather" : "ھاۋارايىغا ئورۇن بەلگىلەڭ",
    "Remove from favorites" : "Remove from favorites",
    "Add as favorite" : "ياقتۇرىدىغاندەك قوشۇڭ",
    "You are not logged in." : "سىز كىرمىدىڭىز.",
    "There was an error getting the weather status information." : "ھاۋارايى ئەھۋالى ئۇچۇرىغا ئېرىشىشتە خاتالىق كۆرۈلدى.",
    "No weather information found" : "ھاۋارايى ئۇچۇرى تېپىلمىدى",
    "Location not found" : "ئورنى تېپىلمىدى",
    "There was an error setting the location address." : "ئورۇن ئادرېسىنى تەڭشەشتە خاتالىق كۆرۈلدى.",
    "There was an error setting the location." : "ئورۇن بەلگىلەشتە خاتالىق كۆرۈلدى.",
    "There was an error saving the mode." : "ھالەتنى ساقلاشتا خاتالىق كۆرۈلدى.",
    "There was an error using personal address." : "شەخسىي ئادرېسنى ئىشلىتىپ خاتالىق كۆرۈلدى.",
    "Unknown weather code" : "نامەلۇم ھاۋارايى كودى",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "باش تاختا دېتالىغا بىرلەشتۈرۈلگەن ھاۋارايى ئەھۋالى.\n    ئىشلەتكۈچىنىڭ ئورنىنى ئاپتوماتىك بەلگىلىگىلى ياكى قولدا بەلگىلىگىلى بولىدۇ. ئاندىن 6 سائەتلىك پەرەز كۆرسىتىلىدۇ.\n    بۇ ھالەتنى كالېندار دېتالىغا ئوخشاش باشقا جايلارغىمۇ بىرلەشتۈرگىلى بولىدۇ."
},
"nplurals=2; plural=(n != 1);");
